# coding=utf-8

import json
import yagmail


def send_mail_util(from_user, pwd, host, to_user, subject, content):
    """
    发送邮件
    :param from_user: 发件人
    :param pwd: 密码
    :param host: 发送地址host
    :param to_user: 收件人
    :param subject: 邮件主题
    :param content: 邮件内容
    :return:
    """
    with yagmail.SMTP(user=from_user, password=pwd, host=host) as yag:
        yag.send(to_user, subject, content)


def json_util(pre_json, to_json_type, **kwargs):
    try:
        return json.loads(pre_json) if to_json_type == 'json_load' else json.dumps(
            pre_json, ensure_ascii=False, **kwargs)
    except:
        return pre_json



# coding=utf-8

from .util import send_mail_util
from .util import json_util


class Tool(object):
    def __init__(self):
        self.mail_from_user = ''  # 邮件发送者账号
        self.mail_from_user_pwd = ''  # 邮件发送者密码
        self.mail_from_host = ''  # 邮件发送host

    def send_mail_msg(self, to_user, subject, content):
        send_mail_util(self.mail_from_user, self.mail_from_user_pwd, self.mail_from_host, to_user, subject, content)

    @staticmethod
    def json_loads(json_str):
        return json_util(json_str, 'json_load', indent=None)

    @staticmethod
    def json_dumps(dict_str, **kwargs):
        return json_util(dict_str, 'json_dump', **kwargs)



# coding:utf-8


from nntool.tools import Tool

# 实例化
tool = Tool()
tool.mail_from_user = 'tech-tm-qa@pin-dao.cn'
tool.mail_from_user_pwd = 'Tm-qa-888888'
tool.mail_from_host = 'smtp.mxhichina.com'

tool.send_mail_msg(to_user='quanningning@pin-dao.cn', subject='测试邮件', content='测试内容')




# coding=utf-8

import io
import sys
import os
from shutil import rmtree
from setuptools import find_packages, setup, Command

name = 'nntoolQ'
version = '0.0.3'
description = 'nntoolQ'
url = "http://autozone-prod.pin-dao.cn/"
email = 'quanningning@pin-dao.cn'
author = 'sunny'
python_version = '>=3.8.0'
install_moudles = ['yagmail']
extras = {}
here = os.path.abspath(os.path.dirname(__file__))

# README.md 描述
try:
    with io.open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
        long_description = '\n' + f.read()
except FileNotFoundError:
    long_description = description


class UploadCommand(Command):
    description = '构建并发布软件包'
    user_options = []

    @staticmethod
    def status(s):
        print('\033[1m{0}\033[0m'.format(s))

    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'nntool/dist'))
        except OSError:
            pass
        self.status('Building Source and Wheel (universal) distribution…')
        os.system('{0} setup.py sdist bdist_wheel --universal'.format(sys.executable))
        self.status('Uploading the package to PyPI via Twine…')
        os.system('twine upload dist/*')
        self.status('Pushing git tags…')
        os.system('git tag v{0}'.format(version))
        os.system('git push --tags')
        sys.exit()


setup(name=name, version=version, description=description,
      long_description=long_description, long_description_content_type='text/markdown',
      author=author, author_email=email, python_requires=python_version, url=url,
      packages=find_packages(exclude=["tests", "*.tests", "*.tests.*", "tests.*"]),
      install_requires=install_moudles, extras_require=extras, include_package_data=True,
      license='MIT', classifiers=[
        'License :: OSI Approved :: MIT License', 'Programming Language :: Python',
        'Programming Language :: Python :: 3'],
      cmdclass={'upload': UploadCommand})
